TorchFont Documentation
=======================

Welcome to the TorchFont documentation.
The sections below provide guidance for users, developers, and contributors.

.. grid:: 2
   :gutter: 2

   .. grid-item-card:: Getting Started
      :link: getting_started/index
      :link-type: doc
      :text-align: center

      Quick installation and first steps to use TorchFont.

   .. grid-item-card:: User Guide
      :link: user_guide/index
      :link-type: doc
      :text-align: center

      Learn how to use TorchFont effectively with practical examples.

   .. grid-item-card:: API Reference
      :link: api/index
      :link-type: doc
      :text-align: center

      Detailed documentation for TorchFont’s public API.

   .. grid-item-card:: Contributor Guide
      :link: contributor_guide/index
      :link-type: doc
      :text-align: center

      Instructions for contributing to TorchFont and setting up a development environment.

Citation
========

If you find TorchFont useful in your work, please consider citing the following BibTeX entry:

.. code-block:: bibtex

   @software{fujioka2025torchfont,
      title        = {TorchFont: A PyTorch-based library for Vector Fonts},
      author       = {Takumu Fujioka},
      year         = 2025,
      journal      = {GitHub repository},
      publisher    = {GitHub},
      howpublished = {\url{https://github.com/fjktkm/torchfont}}
   }

.. toctree::
   :hidden:

   getting_started/index
   user_guide/index
   api/index
   contributor_guide/index
